@@ -18,6 +18,7 @@ import re
 import time
 import importlib
 from datetime import datetime, timedelta
+import pkg_resources
 
 from digital_hydrant.collectors.collector import Collector
 import digital_hydrant.config
@@ -29,23 +30,19 @@ import sqlite3
 class Hydra(Collector):
     def __init__(self, name):
         super(Hydra, self).__init__(name)
+        self.table_name = "unique_ips"
 
         try:
-            self.table_name = "unique_ips"
             self.conn = sqlite3.connect(digital_hydrant.config.db_path)
             self.cursor = self.conn.cursor()
-
-            columns = "id INTEGER PRIMARY KEY AUTOINCREMENT, ip TEXT UNIQUE, last_tested TIMESTAMP"
-            self.cursor.execute(
-                f"CREATE TABLE IF NOT EXISTS {self.table_name} ({columns})"
-            )
         except Exception as err:
-            self.logger.critical(f"Failed to initialize database for Hydra: {err}")
+            self.logger.critical(f"Failed to connect to the database: {err}")
+            exit(1)
 
     def run(self):
         week_ago = datetime.timestamp(datetime.now() - timedelta(weeks=1)) * 1000
         self.cursor.execute(
-            f"SELECT ip FROM unique_ips WHERE last_tested IS NULL or last_tested < {week_ago} ORDER BY last_tested ASC"
+            f"SELECT ip FROM {self.table_name} WHERE last_tested IS NULL or last_tested < {week_ago} ORDER BY last_tested ASC"
         )
 
         records = self.cursor.fetchall()
@@ -71,10 +68,14 @@ class Hydra(Collector):
         self.logger.debug(f"Joining {ip} network, with IP {my_subnet_ip}")
         self.execute(f"ifconfig {iface}:1 {my_subnet_ip}")
 
-        userlist_path = digital_hydrant.config.config.get(self.name, "userlist_path")
-        wordlist_path = digital_hydrant.config.config.get(self.name, "wordlist_path")
-        snmp_wordlist_path = digital_hydrant.config.config.get(
-            self.name, "snmp_wordlist_path"
+        wordlist_path = pkg_resources.resource_filename(
+            "digital_hydrant", "config/hydra/wordlist.txt"
+        )
+        userlist_path = pkg_resources.resource_filename(
+            "digital_hydrant", "config/hydra/userlist.txt"
+        )
+        snmp_wordlist_path = pkg_resources.resource_filename(
+            "digital_hydrant", "config/hydra/snmp_wordlist.txt"
         )
 
         parsed_output = {}
